#!/tvbin/tivosh
#
# sc.tcl v0.1 01/31/2002 [PGM]
#
# This script will create/replace the /Setup/ServiceInfo/DataGroupList object
# in order to activate TivoLution and Showcases. I've NOT included the
# following tokens which are normally set: SF_SerialLogging, SI_TvSec,
# SW_release mainly because I have no idea what they do and they
# sound potentially dangerous. Let me know of any difficulties.
#
# As far as I can tell, this is ALL that needs to be done in order to accept
# the nightly showcases updates. To verify, look at /var/log/scvlog file
# for the releaseshowcases/standard/showcase1-xxxxx-xxx.slice.gz download
# and subsequent status. It should indicate SUCESS or IGNORE_ALREADY_HAVE.
# If you see IGNORE_NOT_IN_GROUP, that's because the DataGroupList object does
# not contain SC_Standard. This script remedies that.
#
# *CAUTION*: This script WILL overwrite any info in the above described object!
#	     Make a note of it's value BEFORE applying this script if you're
#	     unsure.
#

source /tvlib/tcl/tv/mfslib.tcl

#set groups "CP_Standard,CR_Standard,MI_Standard,SC_Standard,SC_TiVoPromotion,SF_SerialLogging,SI_TvSec,SW_released"
set groups "CP_Standard,CR_Standard,MI_Standard,SC_Standard,SC_TiVoPromotion"
set db [dbopen]

try {
    RetryTransaction {
	# Open the setup object
	set setup [db $db open /Setup]

	# Make sure that there is a ServiceInfo object.
	set serviceInfo [dbobj $setup get ServiceInfo]
	if { [llength $serviceInfo] == 0 } {
	    set serviceInfo [db $db createsub ServiceInfo $setup]
	    dbobj $setup set ServiceInfo $serviceInfo
	}

	# Delete DataGroupList then ADD each token
	dbobj $serviceInfo remove DataGroupList
	set dataGroupListList [split $groups ","]
	foreach val $dataGroupListList {
	    dbobj $serviceInfo add DataGroupList $val
	}
    }
} catch errCode {
    puts "error storing Setup: $errCode"
}
dbclose $db
puts "done!"

